@@ -4,13 +4,24 @@ use super::{dos_protection::DosPolicy, world_session::WorldSession};
 pub trait World: Sized + Sync + WorldTime + Send {
     type WorldSessionimplementer: WorldSession<Self> + 'static + Send + Sync;
 
-    cfg_game! {
-        /// Tick
-        fn update(&'static self, _diff: i64) {}
-    }
-    /// Dos Protection (Cmd, Size, Policy)
+    /// Tick
+    fn update(&'static self, _diff: i64) {}
+
+    /// Packet limit.
+    /// (amount, size, policy)
     fn get_packet_limit(&self, _cmd: u16) -> (u16, u32, DosPolicy) {
-        (15, 10 * 2024, DosPolicy::Log)
+        // 15 packets maximum per second.
+        // 10 * 1024 bytes maximum per second.
+        // Log if exceed.
+        (15, 10 * 1024, DosPolicy::Log)
+    }
+
+    /// Limit for all packets per second.
+    /// (amount of packets, size of packets)
+    fn global_limit(&self) -> (u16, u32) {
+        // 50 packets maximum per second.
+        // 5000 bytes maximum per second.
+        (50, 5000)
     }
 }
 
