@@ -13,8 +13,8 @@ use rollo::{
 use rollo_macros::world_time;
 use tokio::{io::AsyncReadExt, net::TcpStream, task::JoinHandle, time::sleep};
 
-#[tokio::test]
-async fn connect_server() {
+#[tokio::test(flavor = "multi_thread", worker_threads = 4)]
+async fn test_connect_server() {
     setup(6666).await;
 
     sleep(Duration::from_secs(1)).await;
